@@ -302,7 +302,7 @@ typedef void* (*cli_column_set)(int var_type, void* var_ptr, int len);
 typedef void* (*cli_column_get)(int var_type, void* var_ptr, int* len);
 
 typedef void* (*cli_column_set_ex)(int var_type, void* var_ptr, int len, 
-				   char_t const* column_name, int statement);
+				   char_t const* column_name, int statement, void const* data_ptr);
 typedef void* (*cli_column_get_ex)(int var_type, void* var_ptr, int* len, 
 				   char_t const* column_name, int statemen);
 
@@ -413,7 +413,7 @@ int GIGABASE_DLL_ENTRY cli_get_next(int statement);
 int GIGABASE_DLL_ENTRY cli_get_prev(int statement);
 
 /*********************************************************************
- * cli_kip
+ * cli_skip
  *     Skip specified number of rows. 
  * Parameters:
  *     statement  - statememt descriptor returned by cli_statement
@@ -564,7 +564,7 @@ int GIGABASE_DLL_ENTRY cli_show_tables(int session, cli_table_descriptor** table
  *     result code as described in cli_result_code enum
  */
 int GIGABASE_DLL_ENTRY cli_create_table(int session, char_t const* tableName, int nFields, 
-					cli_field_descriptor* fields);
+                                        cli_field_descriptor* fields);
 
 /*********************************************************************
  * cli_drop_table
@@ -592,9 +592,34 @@ int GIGABASE_DLL_ENTRY cli_drop_table(int session, char_t const* tableName);
  *     result code as described in cli_result_code enum
  */
 int GIGABASE_DLL_ENTRY cli_alter_index(int session, char_t const* tableName, char_t const* fieldName, 
-				       int newFlags);
+                                       int newFlags);
 
 
+/*********************************************************************
+ * cli_set_error_handler
+ *     Set FastDB erro handler. Handler should be no-return function which perform stack unwind.
+ * Parameters:
+ *     session   - session descriptor as returned by cli_open
+ *     handler   - error handler
+ * Returns:
+ *     previous handler
+ */
+enum cli_error_class { 
+    cli_no_error, 
+    cli_query_error,
+    cli_arithmetic_error,
+    cli_index_out_of_range_error,
+    cli_database_open_error,
+    cli_file_error,
+    cli_out_of_memory_error,
+    cli_deadlock,
+    cli_null_reference_error,
+    cli_lock_revoked,
+    cli_file_limit_exeeded        
+};
+typedef void (*cli_error_handler)(int error, char const* msg, int msgarg); 
+cli_error_handler GIGABASE_DLL_ENTRY cli_set_error_handler(int session, cli_error_handler new_handler);
+
 #ifdef __cplusplus
 }
 #endif
