@@ -13,6 +13,9 @@
 
 BEGIN_GIGABASE_NAMESPACE
 
+/**
+ * Element of the query
+ */
 class GIGABASE_DLL_ENTRY dbQueryElement {
     friend class dbQuery;
     friend class dbCompiler;
@@ -65,6 +68,11 @@ class GIGABASE_DLL_ENTRY dbQueryElement {
 };
 
 
+/**
+ * Allocator of query elements. This class links deallocated elements in the list of free elements,
+ * and reused them in future. So number of system memory allocator invocations is dramatically reduced.
+ * Cleanup of free elements lst is performed by <code>dbDatabase::cleanup()</code> method
+ */
 class GIGABASE_DLL_ENTRY dbQueryElementAllocator { 
     friend class dbDatabase;
     dbMutex&        mutex;
@@ -99,6 +107,25 @@ inline void* dbQueryElement::operator new(size_t size) {
     return dbQueryElementAllocator::instance.allocate(size);
 }
 
+/**
+ * This class represents component of the structure.
+ * It is mostly needed for implementation of application specific database types. For example, look at
+ * <code>dbDate</code> class. It contains <code>int4 jday</code> component which stores time in seconds sinse 1970.
+ * This class defines its own comparison methods:
+ * <PRE>
+ *     dbQueryExpression operator == (char const* field) { 
+ *	   dbQueryExpression expr;
+ *	   expr = dbComponent(field,"jday"),"=",jday;
+ *    	   return expr;
+ *     }
+ * </PRE>
+ * Making it possible to sepcify queries like this (assume that record has column "released" with type dbDate:
+ * <PRE>
+ *     dbQuery q;
+ *     dbDate  date;
+ *     q = date == "released";
+ * </PRE>
+ */
 class GIGABASE_DLL_ENTRY dbComponent {
   public:
     char_t const* structure;
@@ -107,19 +134,25 @@ class GIGABASE_DLL_ENTRY dbComponent {
     dbComponent(char_t const* s, char_t const* f=NULL) : structure(s), field(f) {}
 };
 
+/**
+ * Class representing SubSQL expression.  
+ * It is mostly needed for implementation of application specific database types.
+ * Look at the example in dbComponent class. 
+ * The effect of addeing dbExpression to the query is the same as if this expresion is enclosed in parenthesis.
+ */
 class GIGABASE_DLL_ENTRY dbQueryExpression {
     friend class dbQuery;
     dbQueryElement*  first;
     dbQueryElement** last;
     bool             operand;
 
-    dbQueryExpression& add(dbQueryElement::ElementType type, void const* ptr) {
-	last = &(*last = new dbQueryElement(type, ptr))->next;
+  public:
+    dbQueryExpression& add(dbQueryElement::ElementType type, void const* ptr, dbTableDescriptor* table = NULL) {
+	last = &(*last = new dbQueryElement(type, ptr, table))->next;
 	operand = (type == dbQueryElement::qExpression);
 	return *this;
     }
 
-  public:
     dbQueryExpression& operator = (char_t const* ptr) {
 	first = NULL, last = &first;
 	return add(dbQueryElement::qExpression, ptr);
@@ -137,7 +170,7 @@ class GIGABASE_DLL_ENTRY dbQueryExpression {
     dbQueryExpression& operator,(int4 const& ptr) {
         return add(dbQueryElement::qVarInt4, &ptr);
     }
-    dbQueryExpression& operator,(int8 const& ptr) {
+    dbQueryExpression& operator,(db_int8 const& ptr) {
         return add(dbQueryElement::qVarInt8, &ptr);
     }
     dbQueryExpression& operator,(real4 const& ptr) {
@@ -191,11 +224,37 @@ class GIGABASE_DLL_ENTRY dbQueryExpression {
 	operand = false;
 	return *this;
     }
+    dbQueryExpression& operator += (dbComponent const& comp) { 
+        return *this,comp;
+    }
+    dbQueryExpression& operator += (char const* ptr) { 
+	return add(dbQueryElement::qExpression, ptr);
+    }
+#ifndef NO_MEMBER_TEMPLATES
+    template<class T>
+    dbQueryExpression& operator,(dbReference<T> const& value) { 
+	return add(dbQueryElement::qVarReference, &value, &T::dbDescriptor);
+    }
+
+    template<class T>
+    inline dbQueryExpression& operator,(dbArray< dbReference<T> > const& value) { 
+	return add(dbQueryElement::qVarArrayOfRef, &value, 
+		      &T::dbDescriptor);
+    }
+
+    template<class T>
+    inline dbQueryExpression& operator,(dbArray< dbReference<T> >const* const& value) { 
+ 	return add(dbQueryElement::qVarArrayOfRefPtr, &value, &T::dbDescriptor);
+    }
+#endif
 };
 
 class dbOrderByNode;
 class dbFollowByNode;
 
+/**
+ * Class used for precompiled queries
+ */
 class GIGABASE_DLL_ENTRY dbCompiledQuery {
   public:
     dbExprNode*        tree;
@@ -210,14 +269,21 @@ class GIGABASE_DLL_ENTRY dbCompiledQuery {
     bool               limitSpecified;
 
     enum IteratorInit {
-	StartFromAny,
-	StartFromFirst,
-	StartFromLast,
-	StartFromRef,
-	StartFromArray,
-	StartFromArrayPtr
+        StartFromAny,
+        StartFromFirst,
+        StartFromLast,
+        StartFromRef,
+        StartFromArray,
+        StartFromArrayPtr
     };
     IteratorInit       startFrom;
+    enum IteratorType { 
+        UserDefined      = 0,
+        TraverseForward  = 1, 
+        TraverseBackward = 2
+    };
+    int  iterType;
+
     void const*        root;
 
     void destroy();
@@ -225,15 +291,20 @@ class GIGABASE_DLL_ENTRY dbCompiledQuery {
     bool compiled() { return tree != NULL; }
 
     dbCompiledQuery() {
-	tree = NULL;
-	order = NULL;
-	follow = NULL;
-	table = NULL;
-	startFrom = StartFromAny;
-	limitSpecified = false;
+        tree = NULL;
+        order = NULL;
+        follow = NULL;
+        table = NULL;
+        startFrom = StartFromAny;
+        iterType = UserDefined;
+        limitSpecified = false;
     }
 };
 
+/**
+ * Query class. It is derived from <code>dbCompiledQuery</code> class because each query is compiled only once - when
+ * it is executed first time. All subsequent executions of query used precompiled tree.
+ */
 class GIGABASE_DLL_ENTRY dbQuery : public dbCompiledQuery {
     friend class dbCompiler;
     friend class dbDatabase;
@@ -254,27 +325,27 @@ class GIGABASE_DLL_ENTRY dbQuery : public dbCompiledQuery {
     int                pos; // position of condition in statement
 
     char* dump(char* buf) { 
-	char* p = buf;
-	for (dbQueryElement* elem = elements; elem != NULL; elem = elem->next) { 
-	    p = elem->dump(p);
-	}
-	return buf;
+        char* p = buf;
+        for (dbQueryElement* elem = elements; elem != NULL; elem = elem->next) { 
+            p = elem->dump(p);
+        }
+        return buf;
     }
 
     char* dumpValues(char* buf) { 
-	char* p = buf;
-	for (dbQueryElement* elem = elements; elem != NULL; elem = elem->next) { 
-	    p = elem->dumpValues(p);
-	}
-	return buf;
+        char* p = buf;
+        for (dbQueryElement* elem = elements; elem != NULL; elem = elem->next) { 
+            p = elem->dumpValues(p);
+        }
+        return buf;
     }
 
     dbQuery& append(dbQueryElement::ElementType type, void const* ptr,
-		    dbTableDescriptor* table = NULL)
+                    dbTableDescriptor* table = NULL)
     {
-	nextElement = &(*nextElement=new dbQueryElement(type,ptr,table))->next;
-	operand = (type == dbQueryElement::qExpression);
-	return *this;
+        nextElement = &(*nextElement=new dbQueryElement(type,ptr,table))->next;
+        operand = (type == dbQueryElement::qExpression);
+        return *this;
     }
 
     dbQuery& reset();
@@ -297,62 +368,62 @@ class GIGABASE_DLL_ENTRY dbQuery : public dbCompiledQuery {
     dbQuery& add(dbQueryExpression const& expr);
 
     dbQuery& And(char_t const* str) {
-	if (elements != NULL) {
-	    append(dbQueryElement::qExpression, "and");
-	}
-	return append(dbQueryElement::qExpression, str);
+        if (elements != NULL) {
+            append(dbQueryElement::qExpression, "and");
+        }
+        return append(dbQueryElement::qExpression, str);
     }
 
     dbQuery& Or(char_t const* str) {
-	if (elements != NULL) {
-	    append(dbQueryElement::qExpression, "or");
-	}
-	return append(dbQueryElement::qExpression, str);
+        if (elements != NULL) {
+            append(dbQueryElement::qExpression, "or");
+        }
+        return append(dbQueryElement::qExpression, str);
     }
 
     dbQuery& add(char_t const* str) {
-	return append(operand ? dbQueryElement::qVarString
-		      : dbQueryElement::qExpression, str);
+        return append(operand ? dbQueryElement::qVarString
+                      : dbQueryElement::qExpression, str);
     }
     dbQuery& add(char_t const** str) {
-	return append(dbQueryElement::qVarStringPtr, str);
+        return append(dbQueryElement::qVarStringPtr, str);
     }
     dbQuery& add(char_t** str) {
-	return append(dbQueryElement::qVarStringPtr, str);
+        return append(dbQueryElement::qVarStringPtr, str);
     }
     dbQuery& add(rectangle const& rect) {
         return append(dbQueryElement::qVarRectangle, &rect);
     }
 #ifdef USE_STD_STRING
     dbQuery& add(STD_STRING const& str) { 
-	return append(dbQueryElement::qVarStdString, &str);
+        return append(dbQueryElement::qVarStdString, &str);
     }
     dbQuery& operator,(STD_STRING const& str) { return add(str); }
 #endif
     dbQuery& add(int1 const& value) {
-	return append(dbQueryElement::qVarInt1, &value);
+        return append(dbQueryElement::qVarInt1, &value);
     }
     dbQuery& add (int2 const& value) {
-	return append(dbQueryElement::qVarInt2, &value);
+        return append(dbQueryElement::qVarInt2, &value);
     }
     dbQuery& add (int4 const& value) {
-	return append(dbQueryElement::qVarInt4, &value);
+        return append(dbQueryElement::qVarInt4, &value);
     }
-    dbQuery& add (int8 const& value) {
-	return append(dbQueryElement::qVarInt8, &value);
+    dbQuery& add (db_int8 const& value) {
+        return append(dbQueryElement::qVarInt8, &value);
     }
     dbQuery& add (real4 const& value) {
-	return append(dbQueryElement::qVarReal4, &value);
+        return append(dbQueryElement::qVarReal4, &value);
     }
     dbQuery& add(real8 const& value) {
-	return append(dbQueryElement::qVarReal8, &value);
+        return append(dbQueryElement::qVarReal8, &value);
     }
     dbQuery& add(void const* value) { 
-	return append(dbQueryElement::qVarRawData, value);
+        return append(dbQueryElement::qVarRawData, value);
     }
 #ifndef bool
     dbQuery& add(bool const& value) {
-	return append(dbQueryElement::qVarBool, &value);
+        return append(dbQueryElement::qVarBool, &value);
     }
     dbQuery& operator,(bool const&  value) { return add(value); }
 #endif
@@ -363,7 +434,7 @@ class GIGABASE_DLL_ENTRY dbQuery : public dbCompiledQuery {
     dbQuery& operator,(int1 const&  value) { return add(value); }
     dbQuery& operator,(int2 const&  value) { return add(value); }
     dbQuery& operator,(int4 const&  value) { return add(value); }
-    dbQuery& operator,(int8 const&  value) { return add(value); }
+    dbQuery& operator,(db_int8 const&  value) { return add(value); }
     dbQuery& operator,(real4 const& value) { return add(value); }
     dbQuery& operator,(real8 const& value) { return add(value); }
     dbQuery& operator,(void const*  value) { return add(value); }
@@ -371,92 +442,107 @@ class GIGABASE_DLL_ENTRY dbQuery : public dbCompiledQuery {
     dbQuery& operator,(rectangle const& rect) { return add(rect); }
 
     dbQuery& operator = (const char_t* str) {
-	return reset().append(dbQueryElement::qExpression, str);
+        return reset().append(dbQueryElement::qExpression, str);
     }
 
 #ifndef NO_MEMBER_TEMPLATES
     template<class T>
     dbQuery& operator,(dbReference<T> const& value) { 
-	return append(dbQueryElement::qVarReference, &value, &T::dbDescriptor);
+        return append(dbQueryElement::qVarReference, &value, &T::dbDescriptor);
     }
 
     template<class T>
     dbQuery& operator,(dbArray< dbReference<T> > const& value) { 
-	return append(dbQueryElement::qVarArrayOfRef, &value, 
-		      &T::dbDescriptor);
+        return append(dbQueryElement::qVarArrayOfRef, &value, 
+                      &T::dbDescriptor);
     }
     template<class T>
     dbQuery& operator,(dbArray< dbReference<T> >const* const& value) { 
- 	return append(dbQueryElement::qVarArrayOfRefPtr, &value, &T::dbDescriptor);
+        return append(dbQueryElement::qVarArrayOfRefPtr, &value, &T::dbDescriptor);
     }
 
     template<class T>
     dbQuery& add(dbReference<T> const& value) { 
-	return append(dbQueryElement::qVarReference, &value, &T::dbDescriptor);
+        return append(dbQueryElement::qVarReference, &value, &T::dbDescriptor);
     }
 
     template<class T>
     dbQuery& add(dbArray< dbReference<T> > const& value) { 
-	return append(dbQueryElement::qVarArrayOfRef, &value, 
-		      &T::dbDescriptor);
+        return append(dbQueryElement::qVarArrayOfRef, &value, 
+                      &T::dbDescriptor);
     }
 
     template<class T>
     dbQuery& add(dbArray< dbReference<T> >const* const& value) { 
- 	return append(dbQueryElement::qVarArrayOfRefPtr, &value, &T::dbDescriptor);
+        return append(dbQueryElement::qVarArrayOfRefPtr, &value, &T::dbDescriptor);
     }
 
     template<class T>
     dbQuery& operator = (T const& value) { 
-	return reset().add(value);
-    }	
+        return reset().add(value);
+    }   
 #else
     dbQuery& operator = (dbQueryExpression const& expr) {
-	return reset().add(expr);
+        return reset().add(expr);
     }    
     dbQuery& operator = (rectangle const& expr) {
-	return reset().add(expr);
+        return reset().add(expr);
     }    
 #endif
 
     dbQuery() {
-	elements = NULL;
-	nextElement = &elements;
-	operand = false;
-	pos = 0;
+        elements = NULL;
+        nextElement = &elements;
+        operand = false;
+        pos = 0;
     }
     dbQuery(char_t const* str) {
-	elements = new dbQueryElement(dbQueryElement::qExpression, str);
-	nextElement = &elements->next;
-	operand = true;
-	pos = 0;
+        elements = new dbQueryElement(dbQueryElement::qExpression, str);
+        nextElement = &elements->next;
+        operand = true;
+        pos = 0;
     }
     ~dbQuery() {
-	reset();
+        reset();
     }
 };
 
 #ifdef NO_MEMBER_TEMPLATES
+template<class T>
+inline dbQueryExpression& operator,(dbQueryExpression& expr, dbReference<T> const& value) { 
+    return expr.add(dbQueryElement::qVarReference, &value, &T::dbDescriptor);
+}
+template<class T>
+inline dbQueryExpression& operator,(dbQueryExpression& expr, dbArray< dbReference<T> > const& value) { 
+    return expr.add(dbQueryElement::qVarArrayOfRef, &value, 
+                    &T::dbDescriptor);
+}
+
+template<class T>
+inline dbQueryExpression& operator,(dbQueryExpression& expr, dbArray< dbReference<T> >const* const& value) { 
+    return expr.add(dbQueryElement::qVarArrayOfRefPtr, &value, &T::dbDescriptor);
+}
+
 template<class T>
 inline dbQuery& operator,(dbQuery& query, dbReference<T> const& value) { 
     return query.append(dbQueryElement::qVarReference, &value, 
-			&T::dbDescriptor);
+                        &T::dbDescriptor);
 }
 
 template<class T>
 inline dbQuery& operator,(dbQuery& query, 
-			     dbArray< dbReference<T> > const& value) 
+                             dbArray< dbReference<T> > const& value) 
 { 
     return query.append(dbQueryElement::qVarArrayOfRef, &value, 
-			&T::dbDescriptor);
+                        &T::dbDescriptor);
 }
 
 template<class T>
 inline dbQuery& operator,(dbQuery& query, 
-			  dbArray< dbReference<T> >const* const& value) 
+                          dbArray< dbReference<T> >const* const& value) 
 { 
     return query.append(dbQueryElement::qVarArrayOfRefPtr, &value, 
-			&T::dbDescriptor);
+                        &T::dbDescriptor);
 }
 
 template<class T>
@@ -467,7 +553,7 @@ inline dbQuery& add(dbQuery& query, dbReference<T> const& value) {
 template<class T>
 inline dbQuery& add(dbQuery& query, dbArray< dbReference<T> > const& value) { 
     return query.append(dbQueryElement::qVarArrayOfRef, &value, 
-			&T::dbDescriptor);
+                        &T::dbDescriptor);
 }
 
 template<class T>
@@ -481,34 +567,46 @@ inline dbQuery& add(dbQuery& query, dbArray< dbReference<T> >const* const& value
 class  dbInheritedAttribute;
 class  dbSynthesizedAttribute;
 
+/**
+ * This class represent argument of user defined funtion. 
+ * @see dbUserFunction class.
+ */
 class GIGABASE_DLL_ENTRY  dbUserFunctionArgument { 
   public:
     enum dbArgumentType { 
-	atInteger, 
-	atBoolean, 
-	atString, 
-	atReal, 
-	atReference, 
-	atRawBinary
-    };	
+        atInteger, 
+        atBoolean, 
+        atString, 
+        atReal, 
+        atReference, 
+        atRawBinary
+    };  
     dbArgumentType type; 
     union {
-	real8         realValue;
-	int8          intValue;
-	bool          boolValue;
-	char_t const* strValue;
-	oid_t         oidValue;
-	void*         rawValue;
+        real8         realValue;
+        db_int8          intValue;
+        bool          boolValue;
+        char_t const* strValue;
+        oid_t         oidValue;
+        void*         rawValue;
     } u;
 
   private:
     friend class dbDatabase;
     dbUserFunctionArgument(dbExprNode*             expr, 
-			   dbInheritedAttribute&   iattr, 
-			   dbSynthesizedAttribute& sattr, 
-			   int                     i);
+                           dbInheritedAttribute&   iattr, 
+                           dbSynthesizedAttribute& sattr, 
+                           int                     i);
 };
 
+/**
+ * dbUserFunction class is used to bind user defined functions to the database.
+ * This class contains list of all user functions declared by application and provides method
+ * for locating function by name and adding new user defined functions.
+ * User defined functions can have fro 0 till 3 parameters (of <code>dbUserFunctionArgument</code> type)
+ * and should return integer, boolean, real or string value. Type of the function is detected by overloaded 
+ * constructors. User defined function descriptor is cerated by <code>USER_FUNC</code> macro.
+ */
 class GIGABASE_DLL_ENTRY dbUserFunction {
     friend class dbDatabase;
     friend class dbCompiler;
@@ -520,30 +618,30 @@ class GIGABASE_DLL_ENTRY dbUserFunction {
     static dbUserFunction* list;
 
     enum funcType {
-	fInt2Bool,
-	fReal2Bool,
-	fStr2Bool,
-	fInt2Int,
-	fReal2Int,
-	fStr2Int,
-	fInt2Real,
-	fReal2Real,
-	fStr2Real,
-	fInt2Str,
-	fReal2Str,
-	fStr2Str, 
-	fArg2Bool, 
-	fArg2Int, 
-	fArg2Real, 
-	fArg2Str, 
-	fArgArg2Bool, 
-	fArgArg2Int, 
-	fArgArg2Real, 
-	fArgArg2Str, 
-	fArgArgArg2Bool, 
-	fArgArgArg2Int, 
-	fArgArgArg2Real, 
-	fArgArgArg2Str
+        fInt2Bool,
+        fReal2Bool,
+        fStr2Bool,
+        fInt2Int,
+        fReal2Int,
+        fStr2Int,
+        fInt2Real,
+        fReal2Real,
+        fStr2Real,
+        fInt2Str,
+        fReal2Str,
+        fStr2Str, 
+        fArg2Bool, 
+        fArg2Int, 
+        fArg2Real, 
+        fArg2Str, 
+        fArgArg2Bool, 
+        fArgArg2Int, 
+        fArgArg2Real, 
+        fArgArg2Str, 
+        fArgArgArg2Bool, 
+        fArgArgArg2Int, 
+        fArgArgArg2Real, 
+        fArgArgArg2Str
     };
     int type;
 
@@ -552,93 +650,93 @@ class GIGABASE_DLL_ENTRY dbUserFunction {
   public:
 
     static dbUserFunction* find(char_t const* name) {
-	for (dbUserFunction* func = list; func != NULL; func = func->next) {
-	    if (name == func->name) {
-		return func;
-	    }
-	}
-	return NULL;
+        for (dbUserFunction* func = list; func != NULL; func = func->next) {
+            if (name == func->name) {
+                return func;
+            }
+        }
+        return NULL;
     }
 
     int getParameterType();
 
     int getNumberOfParameters();
 
-    dbUserFunction(bool (__cdecl *f)(int8), char_t* name) {
-	bind(name, (void*)f, fInt2Bool);
+    dbUserFunction(bool (__cdecl *f)(db_int8), char_t* name) {
+        bind(name, (void*)f, fInt2Bool);
     }
     dbUserFunction(bool (__cdecl *f)(real8), char_t* name) {
-	bind(name, (void*)f, fReal2Bool);
+        bind(name, (void*)f, fReal2Bool);
     }
     dbUserFunction(bool (__cdecl *f)(char_t const*), char_t* name) {
-	bind(name, (void*)f, fStr2Bool);
+        bind(name, (void*)f, fStr2Bool);
     }
-    dbUserFunction(int8 (__cdecl *f)(int8), char_t* name) {
-	bind(name, (void*)f, fInt2Int);
+    dbUserFunction(db_int8 (__cdecl *f)(db_int8), char_t* name) {
+        bind(name, (void*)f, fInt2Int);
     }
-    dbUserFunction(int8 (__cdecl *f)(real8), char_t* name) {
-	bind(name, (void*)f, fReal2Int);
+    dbUserFunction(db_int8 (__cdecl *f)(real8), char_t* name) {
+        bind(name, (void*)f, fReal2Int);
     }
-    dbUserFunction(int8 (__cdecl *f)(char_t const*), char_t* name) {
-	bind(name, (void*)f, fStr2Int);
+    dbUserFunction(db_int8 (__cdecl *f)(char_t const*), char_t* name) {
+        bind(name, (void*)f, fStr2Int);
     }
-    dbUserFunction(real8 (__cdecl *f)(int8), char_t* name) {
-	bind(name, (void*)f, fInt2Real);
+    dbUserFunction(real8 (__cdecl *f)(db_int8), char_t* name) {
+        bind(name, (void*)f, fInt2Real);
     }
     dbUserFunction(real8 (__cdecl *f)(real8), char_t* name) {
-	bind(name, (void*)f, fReal2Real);
+        bind(name, (void*)f, fReal2Real);
     }
     dbUserFunction(real8 (__cdecl *f)(char_t const*), char_t* name) {
-	bind(name, (void*)f, fStr2Real);
+        bind(name, (void*)f, fStr2Real);
     }
-    dbUserFunction(char_t* (__cdecl *f)(int8), char_t* name) {
-	bind(name, (void*)f, fInt2Str);
+    dbUserFunction(char_t* (__cdecl *f)(db_int8), char_t* name) {
+        bind(name, (void*)f, fInt2Str);
     }
     dbUserFunction(char_t* (__cdecl *f)(real8), char_t* name) {
-	bind(name, (void*)f, fReal2Str);
+        bind(name, (void*)f, fReal2Str);
     }
     dbUserFunction(char_t* (__cdecl *f)(char_t const*), char_t* name) {
-	bind(name, (void*)f, fStr2Str);
+        bind(name, (void*)f, fStr2Str);
     }
 
     dbUserFunction(bool (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArg2Bool); 
+        bind(name, (void*)f, fArg2Bool); 
     }
     dbUserFunction(char_t* (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArg2Str); 
+        bind(name, (void*)f, fArg2Str); 
     }
-    dbUserFunction(int8 (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArg2Int); 
+    dbUserFunction(db_int8 (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
+        bind(name, (void*)f, fArg2Int); 
     }
     dbUserFunction(real8 (__cdecl *f)(dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArg2Real); 
+        bind(name, (void*)f, fArg2Real); 
     }
 
     dbUserFunction(bool (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArgArg2Bool); 
+        bind(name, (void*)f, fArgArg2Bool); 
     }
     dbUserFunction(char_t* (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArgArg2Str); 
+        bind(name, (void*)f, fArgArg2Str); 
     }
-    dbUserFunction(int8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArgArg2Int); 
+    dbUserFunction(db_int8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+        bind(name, (void*)f, fArgArg2Int); 
     }
     dbUserFunction(real8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArgArg2Real); 
+        bind(name, (void*)f, fArgArg2Real); 
     }
 
 
     dbUserFunction(bool (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArgArgArg2Bool); 
+        bind(name, (void*)f, fArgArgArg2Bool); 
     }
     dbUserFunction(char_t* (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArgArgArg2Str); 
+        bind(name, (void*)f, fArgArgArg2Str); 
     }
-    dbUserFunction(int8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArgArgArg2Int); 
+    dbUserFunction(db_int8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
+        bind(name, (void*)f, fArgArgArg2Int); 
     }
     dbUserFunction(real8 (__cdecl *f)(dbUserFunctionArgument&, dbUserFunctionArgument&, dbUserFunctionArgument&), char_t* name) { 
-	bind(name, (void*)f, fArgArgArg2Real); 
+        bind(name, (void*)f, fArgArgArg2Real); 
     }
 };
 
