@@ -38,7 +38,7 @@
 #endif
 #else
 #ifdef _AIX
-#define int8 int8bits
+#define INT8_IS_DEFINED
 #endif
 #ifndef NO_PTHREADS
 #ifndef _REENTRANT
@@ -53,6 +53,17 @@
 #endif /* __VACPP_MULTI__ */
 
 
+#ifdef _WINCE
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <limits.h>
+#include <stdarg.h>
+#include <tchar.h>
+#include "wince.h"
+
+#else
+
 #include <stdio.h>
 #include <stddef.h>
 #include <stdlib.h>
@@ -68,6 +79,8 @@
 #include <ctype.h>
 #endif
 
+#endif
+
 #ifndef __IBMCPP__
 BEGIN_GIGABASE_NAMESPACE
 #endif
@@ -106,8 +119,13 @@ typedef wchar_t char_t;
 #define STRSTR(x, y)  wcsstr(x, y)
 #define STRXFRM(x,y,z) wcsxfrm(x, y, z)
 #define STRFTIME(a,b,c,d) wcsftime(a,b,c,d)
+#ifdef _WINCE
+#define REMOVE_FILE(s) DeleteFile(s)
+#define RENAME_FILE(p, q) MoveFile(p, q)
+#else
 #define REMOVE_FILE(s) _wremove(s)
 #define RENAME_FILE(p, q) _wrename(p, q)
+#endif
 #define GETENV(x)     _wgetenv(x)
 #define T_EOF         WEOF
 #define STD_STRING    std::wstring
@@ -149,21 +167,33 @@ typedef char char_t;
 #define _T(x) x
 #endif
 
-typedef signed char    int1;
-typedef unsigned char  nat1;
+inline void strlower(char_t* dst, const char_t* src)
+{
+    int ch;
+    do {
+	ch = *src++;
+	*dst++ = TOLOWER(ch);
+    } while (ch != 0);
+}
 
-typedef signed short   int2;
-typedef unsigned short nat2;
+typedef signed char    db_int1;
+typedef unsigned char  db_nat1;
 
-typedef signed int     int4;
-typedef unsigned int   nat4;
+typedef signed short   db_int2;
+typedef unsigned short db_nat2;
 
-typedef unsigned char  byte;
+typedef signed int     db_int4;
+typedef unsigned int   db_nat4;
+
+typedef unsigned char  db_byte;
+
+typedef float  db_real4;
+typedef double db_real8;
 
 
 #if defined(_WIN32) && !defined(__MINGW32__)
-typedef unsigned __int64 nat8;
-typedef __int64          int8;
+typedef unsigned __int64 db_nat8;
+typedef __int64          db_int8;
 #if defined(__IBMCPP__)
 #define INT8_FORMAT "%lld"
 #define T_INT8_FORMAT _T("%lld")
@@ -173,22 +203,40 @@ typedef __int64          int8;
 #endif
 #define CONST64(c)  c
 #else
-#undef int8
 #if SIZEOF_LONG == 8
-typedef unsigned long nat8;
-typedef signed   long int8;
+typedef unsigned long db_nat8;
+typedef signed   long db_int8;
 #define INT8_FORMAT "%ld"
 #define T_INT8_FORMAT _T("%ld")
 #define CONST64(c)  c##L
 #else
-typedef unsigned long long nat8;
-typedef signed   long long int8;
+typedef unsigned long long db_nat8;
+typedef signed   long long db_int8;
 #define INT8_FORMAT "%lld"
 #define T_INT8_FORMAT _T("%lld")
 #define CONST64(c)  c##LL
 #endif
 #endif
 
+// This mapping is done for compatibility reasons
+typedef db_int1 int1;
+typedef db_nat1 nat1;
+typedef db_int2 int2;
+typedef db_nat2 nat2;
+typedef db_int4 int4;
+typedef db_nat4 nat4;
+
+typedef db_byte byte;
+
+typedef db_real4 real4;
+typedef db_real8 real8;
+
+typedef db_nat8 nat8;
+
+#ifndef INT8_IS_DEFINED
+typedef db_int8 int8;
+#endif
+
 
 #if !defined(bool) && (defined(__SUNPRO_CC) || defined(__IBMCPP__))
 #define bool  char
@@ -196,23 +244,20 @@ typedef signed   long long int8;
 #define false (0)
 #endif
 
-#define nat8_low_part(x)  ((nat4)(x))
-#define int8_low_part(x)  ((int4)(x))
+#define nat8_low_part(x)  ((db_nat4)(x))
+#define int8_low_part(x)  ((db_int4)(x))
 #if defined(_MSC_VER) // bug in MVC 6.0
-#define nat8_high_part(x) (sizeof(x) < 8 ? 0 : ((nat4)((nat8)(x)>>32)))
-#define int8_high_part(x) (sizeof(x) < 8 ? 0 : ((int4)((int8)(x)>>32)))
+#define nat8_high_part(x) (sizeof(x) < 8 ? 0 : ((db_nat4)((db_nat8)(x)>>32)))
+#define int8_high_part(x) (sizeof(x) < 8 ? 0 : ((db_int4)((db_int8)(x)>>32)))
 #else
-#define nat8_high_part(x) ((nat4)((nat8)(x)>>32))
-#define int8_high_part(x) ((int4)((int8)(x)>>32))
+#define nat8_high_part(x) ((db_nat4)((db_nat8)(x)>>32))
+#define int8_high_part(x) ((db_int4)((db_int8)(x)>>32))
 #endif
 
-#define cons_nat8(hi, lo) ((((nat8)(hi)) << 32) | (nat4)(lo))
-#define cons_int8(hi, lo) ((((int8)(hi)) << 32) | (nat4)(lo))
+#define cons_nat8(hi, lo) ((((db_nat8)(hi)) << 32) | (db_nat4)(lo))
+#define cons_int8(hi, lo) ((((db_int8)(hi)) << 32) | (db_nat4)(lo))
 
-#define MAX_NAT8  nat8(-1)
-
-typedef float  real4;
-typedef double real8;
+#define MAX_NAT8  db_nat8(-1)
 
 #ifndef BIG_ENDIAN
 #define BIG_ENDIAN      4321    /* most-significant byte first (IBM, net) */
